Creates an object of class irp_prediction_domain
irp_prediction_domain.RdCreates an object of class irp_prediction_domain
Arguments
- x
A data frame with a row for each wavenumber value in the training data and the following columns:
xA numeric value representing the wavenumber value [cm\(^{-1}\)].
yminA numeric value representing the minimum predictor variable value in the training data at this wavenumber value.
ymaxA numeric value representing the maximum predictor variable value in the training data at this wavenumber value.
xmay contain additional columns.